# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTIBILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

bl_info = {
    "name" : "Fast Language Switch",
    "author" : "BlenderCN - Kirk.",
    "description" : "Fast change the language of the interface",
    "blender" : (4, 2, 0),
    "version" : (0, 0, 4),
    "location" : "Top menu",
    "warning" : "",
    "category" : "Generic",
    "doc_url": "https://www.blendercn.org/" "",
}

import bpy,json

class BasicMenu(bpy.types.Menu):
    bl_idname = "OBJECT_MT_switch_language"
    bl_label = "Language"
    
    def draw(self, context):
        layout = self.layout
        box = layout.box()
        box.operator(BLCN_OT_switch_language.bl_idname)

class BLCN_OT_switch_language(bpy.types.Operator):
    bl_idname = "blcn.switch_language"
    bl_label = "Language"
    bl_description = "Fast change the language of the interface"
    bl_options = {"REGISTER"}
    
    def execute(self, context):
        pref = context.preferences.addons[__package__].preferences
        print(__package__)
        now = context.preferences.view.language
        if now == pref.language:
            context.preferences.view.language = pref.other_language
        else:
            context.preferences.view.language = pref.language
        context.preferences.view.use_translate_new_dataname
        return {'FINISHED'}

class BLCN_OT_save(bpy.types.Operator):
    bl_idname = "blcn.save"
    bl_label = "Save"
    bl_description = "Save the current language"
    bl_options = {"REGISTER"}
    
    def execute(self, context):
        pref = context.preferences.addons[__package__].preferences
        data = {}
        data["language"] = pref.language
        data["other_language"] = pref.other_language
        data_str = json.dumps(data)
        with open("cfg.json", "w", encoding="utf-8") as f:
            f.write(data_str)
            self.report = {"INFO": "Save success"}
        return {'FINISHED'}

language_items = [
            ('en_US', 'English (English)', ''),
            ('zh_HANS', 'Simplified Chinese (简体中文)', ''),
            ('zh_HANT', 'Traditional Chinese (繁體中文)', ''),
            ('ja_JP', 'Japanese (日本語)', ''),
            ('ko_KR', 'Korean (한국어)', ''),
            ('ru_RU', 'Russian (Русский)', ''),
            ('uk_UA', 'Ukrainian (Українська)', ''),
            ('es', 'Spanish (Español)', ''),
            ('fr_FR', 'French (Français)', ''),
            ('it_IT', 'Italian (Italiano)', ''),
            ('de_DE', 'German (Deutsch)', ''),
        ]

# language_items_dict = {
#     'en_US': 'English (English)',
#     'zh_HANS': 'Simplified Chinese (简体中文)',
#     'zh_HANT': 'Traditional Chinese (繁體中文)',
#     'ja_JP': 'Japanese (日本語)',
#     'ko_KR': 'Korean (한국어)',
#     'ru_RU': 'Russian (Русский)',
#     'uk_UA': 'Ukrainian (Українська)',
#     'es': 'Spanish (Español)',
#     'fr_FR': 'French (Français)',
#     'it_IT': 'Italian (Italiano)',
#     'de_DE': 'German (Deutsch)',
# }

class BLCN_AddonPreferences(bpy.types.AddonPreferences):
    bl_idname = __package__

    language : bpy.props.EnumProperty(
        name="Language",
        items=language_items,description="The language to be switch",
    )

    other_language : bpy.props.EnumProperty(
        name="Language",
        items=language_items,description="The other language to be switch",
    )

    def draw(self, context):
        layout = self.layout

        layout.prop(self, "language")   

        layout.prop(self, "other_language")

        layout.operator(BLCN_OT_save.bl_idname)
        
import os
def register():
    ...
    bpy.utils.register_class(BLCN_OT_switch_language)
    bpy.utils.register_class(BLCN_OT_save)
    bpy.utils.register_class(BasicMenu)
    bpy.utils.register_class(BLCN_AddonPreferences)
    bpy.types.TOPBAR_MT_editor_menus.append(BasicMenu.draw)

    data_str = ""
    if os.path.exists("cfg.json"):
        with open("cfg.json", "r", encoding="utf-8") as f:
            data_str = f.read()
    if data_str == "":
        data = {}
        data["language"] = "en_US"
        data["other_language"] = "zh_HANS"
    else:
        data = json.loads(data_str)
        pref = bpy.context.preferences.addons[__package__].preferences
        pref.language = data["language"]
        pref.other_language = data["other_language"]

def unregister():
    ...
    bpy.types.TOPBAR_MT_editor_menus.remove(BasicMenu.draw)
    
    bpy.utils.unregister_class(BLCN_OT_switch_language)
    bpy.utils.unregister_class(BLCN_OT_save)
    bpy.utils.unregister_class(BasicMenu)
    bpy.utils.unregister_class(BLCN_AddonPreferences)
